#include <stdint.h>
#include "accel3.h"

sbit ACCEL_3_CS at RC2_bit;
sbit ACCEL_3_CS_DIR at TRISC2_bit;

void main()
{
  uint8_t address = 0x18;
  xyz_t* my_coords;
  uint8_t thresh = 1;
  uint8_t duration = 15;
  char text[50];

    //UART Initialization
  UART2_Init(57600);
  Delay_ms(300);

    //GPIO Outputs
  ACCEL_3_CS_DIR = 1;
  Delay_ms(300);


  I2C1_Init( 100000 );
  Delay_ms(500);

  UART2_Write_Text( "I2C Initialized" );
  UART2_Write_Text( "\r\n" );

    //Accel 3 Initialization
  accel3_init( address, NORMAL, HZ_100, I2C );
  accel3_hp_filter_mode_select( HP_NORMAL_MODE );
  accel3_filtered_data_selection_enable( true );


  while(1)
  {
     my_coords = accel3_get_xyz();

     //sprinti( text, " x: %d y: %d z: %d ", my_coords->x_pos, my_coords->y_pos, my_coords->z_pos );
     IntToStr( my_coords->x_pos, text );
     UART2_Write_Text( " x: " );
     UART2_Write_Text( text );
     IntToStr( my_coords->y_pos, text );
     UART2_Write_Text( " y: " );
     UART2_Write_Text( text );
     IntToStr( my_coords->z_pos, text );
     UART2_Write_Text( " z: " );
     UART2_Write_Text( text );

     UART2_Write_Text( "\r\n" );
     Delay_ms(1000);
  }

}

void get_calibration( void )
{
  xyz_t* my_coords;
  int32_t sum[3] = {0};
  char* tag[] = {"Z+", "Z-", "Y+", "Y-", "X+", "X-"};
  int16_t dataBuf[6][3] = {0};
  char text[70] = { 0 };
  char temp_str[3] = { 0 };
  uint8_t timer = 0;
  uint8_t i = 0;
  int16_t axis_x;
  int16_t axis_y;
  int16_t axis_z;

  Delay_ms(1000);
  for ( timer = 0; timer < 6; timer++)
  {
    UART2_Write_Text(" Please Turn " );
    UART2_Write_Text( tag[timer] );
    UART2_Write_Text( " up\r\n" );
    Delay_ms(2000);
    for ( i = 0; i < 5; i++)
    {
      UART2_Write_Text( "Start will be in " );
      IntToStr( ( 5 - i ), text );
      UART2_Write_Text( text );
      UART2_Write_Text( " seconds\r\n" );
      Delay_ms(1000);
    }
    UART2_Write_Text( "Calculating\r\n" );
    for ( i = 0 ; i < 100; i++)
    {
      my_coords = accel3_get_xyz_raw();
      sum[0] += my_coords->x_pos;
      sum[1] += my_coords->y_pos;
      sum[2] += my_coords->z_pos;
    }
    Delay_ms(20);

    dataBuf[timer][0] = sum[0] / 100;
    dataBuf[timer][1] = sum[1] / 100;
    dataBuf[timer][2] = sum[2] / 100;
    sum[0] = sum[1] = sum[2] = 0;
    UART2_Write_Text( "Calculate Success\r\n" );
    Delay_ms(1000);
  }

  axis_x = (dataBuf[4][0] + dataBuf[5][0]) * 0.3 + (dataBuf[0][0] + dataBuf[1][0] + dataBuf[2][0] + dataBuf[3][0]) / 10;
  IntToStr( axis_x, text );
  UART2_Write_Text(" Adjust Value of X is " );
  UART2_Write_Text( text );
  UART2_Write_Text( "\r\n" );
  axis_y = (dataBuf[2][1] + dataBuf[3][1]) * 0.3 + (dataBuf[0][1] + dataBuf[1][1] + dataBuf[4][1] + dataBuf[5][1]) / 10;
  IntToStr( axis_y, text );
  UART2_Write_Text(" Adjust Value of Y is " );
  UART2_Write_Text( text );
  UART2_Write_Text( "\r\n" );
  axis_z = (dataBuf[0][2] + dataBuf[1][2]) * 0.3 + (dataBuf[2][2] + dataBuf[3][2] + dataBuf[4][2] + dataBuf[5][2]) / 10;
  IntToStr( axis_z, text );
  UART2_Write_Text(" Adjust Value of Z is " );
  UART2_Write_Text( text );
  UART2_Write_Text( "\r\n" );
  Delay_ms(3000);
  set_x( axis_x );
  set_y( axis_y );
  set_z( axis_z );
  UART2_Write_Text( "\r\n\r\n----- Calibration Finished -----\r\n\r\n" );

}